@@ -4,8 +4,9 @@ from ecommercetools.seo.sitemaps import get_sitemap
 from ecommercetools.seo.google_pagespeed_insights import get_core_web_vitals
 from ecommercetools.seo.google_knowledge_graph import get_knowledge_graph
 from ecommercetools.seo.google_search_console import query_google_search_console
+from ecommercetools.seo.google_search_console import query_google_search_console_compare
 from ecommercetools.seo.google_autocomplete import google_autocomplete
 from ecommercetools.seo.google_search import get_indexed_pages
 from ecommercetools.seo.google_search import get_serps
 from ecommercetools.seo.scraping import scrape_site
-
+from ecommercetools.seo.testing import seo_test
\ No newline at end of file
